@@ -44,7 +44,6 @@ else:
 import artellapipe
 from artellapipe.libs import artella as artella_lib
 from artellapipe.libs.artella.core import artellalib, artellaclasses
-from artellapipe.libs.naming.core import naminglib
 from artellapipe.core import defines, config, node, sequence, shot
 from artellapipe.utils import resource
 
@@ -198,11 +197,13 @@ class ArtellaProject(object):
         self.create_shelf()
         self.create_menu()
         self._tray = self.create_tray()
-        self.create_assets_manager()
+        self.create_names_manager()
         self.create_files_manager()
+        self.create_assets_manager()
         self.create_tags_manager()
         self.create_shaders_manager()
         self.create_playblasts_manager()
+        self.create_pyblish_manager()
         self.create_production_tracker()
         self.update_project()
         self._update_dcc_ui()
@@ -338,26 +339,6 @@ class ArtellaProject(object):
 
         return 'Not Found!'
 
-    def solve_name(self, rule_name, *args, **kwargs):
-        """
-        Resolves name with given rule and attributes
-        :param rule_name: str
-        :param args: list
-        :param kwargs: dict
-        """
-
-        name_lib = naminglib.ArtellaNameLib()
-        current_rule = name_lib.active_rule()
-        name_lib.set_active_rule(rule_name)
-        solved_name = name_lib.solve(*args, **kwargs)
-        if current_rule:
-            if rule_name != current_rule.name:
-                name_lib.set_active_rule(current_rule.name)
-        else:
-            name_lib.set_active_rule(None)
-
-        return solved_name
-
     def init_settings(self):
         """
         Function that initializes project settings file
@@ -517,6 +498,17 @@ class ArtellaProject(object):
 
         return menu_manager
 
+    def create_names_manager(self):
+        """
+        Creates instance of the assets manager used by the project
+        :return: ArtellaAssetsManager
+        """
+
+        names_manager = artellapipe.NamesMgr()
+        names_manager.set_project(self)
+
+        return names_manager
+
     def create_assets_manager(self):
         """
         Creates instance of the assets manager used by the project
@@ -575,6 +567,17 @@ class ArtellaProject(object):
 
         return playblasts_manager
 
+    def create_pyblish_manager(self):
+        """
+       Creates instance of the Pyblish plugins manager used by the project
+       :return: ArtellaPyblishPluginsManager
+       """
+
+        pyblish_manager = artellapipe.PyblishMgr()
+        pyblish_manager.set_project(self)
+
+        return pyblish_manager
+
     def create_production_tracker(self):
         """
         Creates instance of the production tracker used by the project
@@ -1036,19 +1039,6 @@ class ArtellaProject(object):
 
         return re.compile(r"{}".format(self._shot_regex))
 
-    # ==========================================================================================================
-    # PUBLISHER
-    # ==========================================================================================================
-
-    def get_publisher_plugin_paths(self):
-        """
-        Function that registers all plugins available for Artella Publisher
-        """
-
-        return [
-            path_utils.clean_path(os.path.join(self.get_project_path(), 'tools', 'publisher', 'plugins'))
-        ]
-
     # ==========================================================================================================
     # PRIVATE
     # ==========================================================================================================
