@@ -76,7 +76,7 @@ def init(do_reload=False, dev=False):
     artella_importer.import_packages(
         order=packages_order,
         only_packages=False,
-        skip_modules=['artellapipe.libs', 'artellapipe.dccs'])
+        skip_modules=['artellapipe.libs'])
     if do_reload:
         artella_importer.reload_all()
 
